Package: MEAanalysis
Version: 0.1.0
Title: Analyse and Visualise Multi Electrode Array Burst Data
Authors@R: person(given = "Emily", 
                  family = "Gordon",
                  role = c("aut", "cre"), 
                  email = "emily.gordon@wadham.ox.ac.uk")
Maintainer: Emily Gordon <emily.gordon@wadham.ox.ac.uk>
Description: Analyse and visualise multi electrode array data at the single electrode and whole well level, downstream of 'AxIS Navigator 3.6.2 Software' processing. 
             Compare bursting parameters between time intervals and recordings using the bar chart visualisation functions. Compatible with 12- and 24- well plates.
License: GPL (>= 2)
Imports: data.table (>= 1.15.4), dplyr (>= 1.1.4), ggplot2 (>= 3.5.0),
        janitor (>= 2.2.0), kableExtra (>= 1.4.0), knitr (>= 1.46),
        readr (>= 2.1.5), readxl (>= 1.4.3), reshape2 (>= 1.4.4),
        stringr (>= 1.5.1), tidyr (>= 1.3.1), tidyverse (>= 2.0.0)
Depends: R (>= 4.3.0)
Encoding: UTF-8
RoxygenNote: 7.3.1
LazyData: true
Suggests: rmarkdown (>= 2.26), testthat (>= 3.2.1)
VignetteBuilder: knitr
Config/testthat/edition: 3
URL: https://egordon2.github.io/MEA-analysis-package/
BugReports: https://github.com/egordon2/MEA-analysis-package/issues
NeedsCompilation: no
Packaged: 2025-05-02 14:34:24 UTC; Emily Gordon
Author: Emily Gordon [aut, cre]
Repository: CRAN
Date/Publication: 2025-05-06 08:30:06 UTC
Built: R 4.6.0; ; 2026-04-25 13:58:25 UTC; unix
