# Generated by roxygen2: do not edit by hand

export(MEA_heatmap)
export(create_electrode_dataset)
export(create_synchrony_dataset)
export(electrode_burst_duration)
export(electrode_mean_burst_ISI)
export(electrode_number_of_bursts)
export(electrode_spikes_per_burst)
export(single_electrode_barchart)
export(well_barchart)
export(well_burst_duration)
export(well_mean_burst_ISI)
export(well_number_of_bursts)
export(well_spikes_per_burst)
importFrom(data.table,melt)
importFrom(data.table,setDT)
importFrom(data.table,setcolorder)
importFrom(data.table,transpose)
importFrom(dplyr,"%>%")
importFrom(dplyr,add_count)
importFrom(dplyr,between)
importFrom(dplyr,coalesce)
importFrom(dplyr,contains)
importFrom(dplyr,count)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,position_jitterdodge)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_grey)
importFrom(ggplot2,theme)
importFrom(janitor,row_to_names)
importFrom(readr,read_csv)
importFrom(readxl,read_excel)
importFrom(readxl,read_xls)
importFrom(readxl,read_xlsx)
importFrom(stats,sd)
importFrom(stringr,str_detect)
importFrom(stringr,str_sub)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
